*****************************************************************************************
* FILE NAME:     SASOUT20_LLCP.SAS                                                      *
* DESCRIPTION:   THIS PROGRAM CONVERTS A STATES ASCII DATAFILE OF COMPLETES LOCATED AT  *
*                <DATAIN> FILEREF, INTO A SAS DATABASE STORED AT <DATAOUT> LIBREF       *
* REFERENCES:                                                                           *
* INPUT       DATAIN           FILEREF OF ASCII DATAFILE OF COMPLETES                   *
* FORMATS     FORMATS.SAS7BCAT      SAS FORMATS DATABASE                                *
* OUTPUT      DATAOUT.SASDATA  SAS DATABASE VERSION OF ASCII DATA AS SPECIFIED IN       *
*                              <DATAIN> FILEREF                                         *
* UPDATED - 06/01/2021                                                                  *
*****************************************************************************************;
********************************
* Clear Output and Log Windows *
********************************;
DM OUTPUT 'clear' continue;
DM LOG    'clear' continue;
**********************************
* DEFINE SAS ENVIRONMENT OPTIONS *
**********************************;
OPTIONS PAGENO=1 NOFMTERR;
***************************************
* CLEAR EXISTING TITLES AND FOOTNOTES *
***************************************;
TITLE ;
FOOTNOTE ;
RUN ;
******************************************************************
* INSTRUCTIONS:                                                  *
* SPECIFY PATH OF WHERE ASCII DATAFILE IS STORED                 *
* SPECIFY PATH OF WHERE SAS DATASET IS TO BE STORED              *
* SPECIFY PATH OF WHERE SAS FORMAT LIBRARY IS STORED             *
* SPECIFY PATH OF WHERE THE FORMAT ASSIGNMET STATEMENT IS STORED *
******************************************************************;

*FILENAME DATAIN '<PATH OF INPUT STATE ASCII DATAFILE OF COMPLETES>' LRECL = 2037 ;
*****************************************************************************
* EXAMPLE:                                                                  *
*       FILENAME DATAIN 'C:\BRFSS\2020\LLCP2020.ASC' LRECL = 2037           *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

*LIBNAME DATAOUT V7 '<PATH OF PERMANENTLY STORED SAS DATASET VERSION OF DATAIN FILEREF>'  ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME DATAOUT 'C:\'                                            *
*          A SAS DATABASE WILL BE STORED AT C:\SASDATA.sas7bdat             *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*LIBNAME LIBRARY '<PATH OF STORED SAS FORMAT20.SAS7BCAT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME LIBRARY 'C:\'                                            *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*FILENAME FORMATIN '<PATH OF FORMAT ASSIGNMENT STATEMENT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          FILENAME FORMATIN 'C:\FORMATSTATEMENT.SAS'                       *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

DATA DATAOUT.SASDATA ;
INFILE DATAIN MISSOVER ;
INPUT
_STATE        1-2                     /* Record Identification */
FMONTH        17-18
IDATE         $19-26
IMONTH        $19-20
IDAY          $21-22
IYEAR         $23-26
DISPCODE      32-35
SEQNO         $36-45
_PSU          36-45
CTELENM1      63                      /* Land Line Introduction */
PVTRESD1      64
COLGHOUS      65
STATERE1      66
CELPHONE      67
LADULT1       68
COLGSEX       69
NUMADULT      70-71
LANDSEX       72
NUMMEN        73-74
NUMWOMEN      75-76
RESPSLCT      77
SAFETIME      78                      /* Cell Phone Introduction */
CTELNUM1      79
CELLFON5      80
CADULT1       81
CELLSEX       82
PVTRESD3      83
CCLGHOUS      84
CSTATE1       85
LANDLINE      88
HHADULT       89-90
SEXVAR        91                      /* Respondent Sex */
GENHLTH       101                     /* Section 1: Health Status */
PHYSHLTH      102-103                 /* Section 2: Healthy Days */
MENTHLTH      104-105
POORHLTH      106-107
HLTHPLN1      108                     /* Section 3: Health Care Access */
PERSDOC2      109
MEDCOST       110
CHECKUP1      111
EXERANY2      112                     /* Section 4: Exercise */
SLEPTIM1      113-114                 /* Section 5: Inadequate Sleep */
CVDINFR4      115                     /* Section 6: Chronic Health Conditions */
CVDCRHD4      116
CVDSTRK3      117
ASTHMA3       118
ASTHNOW       119
CHCSCNCR      120
CHCOCNCR      121
CHCCOPD2      122
HAVARTH4      123
ADDEPEV3      124
CHCKDNY2      125
DIABETE4      126
DIABAGE3      127-128
LASTDEN4      129                     /* Section 7: Oral Health */
RMVTETH4      130
MARITAL       167
EDUCA         168
RENTHOM1      169
NUMHHOL3      178
NUMPHON3      179
CPDEMO1B      180
VETERAN3      181
EMPLOY1       182
CHILDREN      183-184
INCOME2       185-186
PREGNANT      187
WEIGHT2       188-191
HEIGHT3       192-195
DEAF          196                     /* Section 9: Disability */
BLIND         197
DECIDE        198
DIFFWALK      199
DIFFDRES      200
DIFFALON      201
SMOKE100      202                     /* Section 10: Tobacco Use */
SMOKDAY2      203
STOPSMK2      204
LASTSMK2      205-206
USENOW3       207
ALCDAY5       208-210                 /* Section 11: Alcohol Consumption */
AVEDRNK3      211-212
DRNK3GE5      213-214
MAXDRNKS      215-216
FLUSHOT7      217                     /* Section 12: Immunization */
FLSHTMY3      218-223
SHINGLE2      224
PNEUVAC4      225
FALL12MN      226-227                 /* Section 13: Falls */
FALLINJ4      228-229
SEATBELT      230                     /* Section 14: Seatbelt Use and Drinking and Driving */
DRNKDRI2      231-232
HADMAM        233                     /* Section 15: Breast and Cervical Cancer Screening */
HOWLONG       234
HADPAP2       235
LASTPAP2      236
HPVTEST       237
HPLSTTST      238
HADHYST2      239
PCPSAAD3      240                     /* Section 16: Prostate Cancer Screening */
PCPSADI1      241
PCPSARE1      242
PSATEST1      243
PSATIME       244
PCPSARS1      245
COLNSCPY      246                     /* Section 17: Colorectal Cancer Screening */
COLNTEST      247
SIGMSCPY      248
SIGMTEST      249
BLDSTOL1      250
LSTBLDS4      251
STOOLDNA      252
SDNATEST      253
VIRCOLON      254
VCLNTEST      255
HIVTST7       256                     /* Section 18: HIV/AIDS */
HIVTSTD3      257-262
HIVRISK5      263
PDIABTST      264                     /* Module 1: Pre-Diabetes */
PREDIAB1      265
INSULIN1      266                     /* Module 2: Diabetes */
BLDSUGAR      267-269
FEETCHK3      270-272
DOCTDIAB      273-274
CHKHEMO3      275-276
FEETCHK       277-278
EYEEXAM1      279
DIABEYE       280
DIABEDU       281
TOLDCFS       282                     /* Module 3: ME/CFS */
HAVECFS       283
WORKCFS       284
TOLDHEPC      285                     /* Module 4: Hepatitis Treatment */
TRETHEPC      286
PRIRHEPC      287
HAVEHEPC      288
HAVEHEPB      289
MEDSHEPB      290
HLTHCVR1      291-292                 /* Module 5: Health Care Access */
CIMEMLOS      293                     /* Module 6: Cognitive Decline */
CDHOUSE       294
CDASSIST      295
CDHELP        296
CDSOCIAL      297
CDDISCUS      298
CAREGIV1      299                     /* Module 7: Caregiver */
CRGVREL4      300-301
CRGVLNG1      302
CRGVHRS1      303
CRGVPRB3      304-305
CRGVALZD      306
CRGVPER1      307
CRGVHOU1      308
CRGVEXPT      309
ECIGARET      310                     /* Module 8: E-Cigarettes */
ECIGNOW       311
MARIJAN1      312-313                 /* Module 9: Marijuana Use */
USEMRJN2      314
RSNMRJN1      315
LCSFIRST      316-318                 /* Module 10: Lung Cancer Screening */
LCSLAST       319-321
LCSNUMCG      322-324
LCSCTSCN      325
CNCRDIFF      326                     /* Module 11: Cancer Survivorship: Type of Cancer */
CNCRAGE       327-328
CNCRTYP1      329-330
CSRVTRT3      331                     /* Module 12: Cancer Survivorship: Course of Treatment */
CSRVDOC1      332-333
CSRVSUM       334
CSRVRTRN      335
CSRVINST      336
CSRVINSR      337
CSRVDEIN      338
CSRVCLIN      339
CSRVPAIN      340                     /* Module 13: Cancer Survivorship: Pain Management */
CSRVCTL2      341
PCPSADE1      342                     /* Module 14: Prostate Cancer Screening Decision Making */
PCDMDEC1      343
HPVADVC4      344                     /* Module 15: HPV Vaccination */
HPVADSHT      345-346
TETANUS1      347                     /* Module 16: Tetanus Diphtheria (Tdap) (Adults) */
IMFVPLA1      348-349                 /* Module 17: Place of Flu Vaccination */
BIRTHSEX      550                     /* Module 19: Sex at Birth */
SOMALE        551
SOFEMALE      552
TRNSGNDR      553
ACEDEPRS      554                     /* Module 21: Adverse Childhood Experience */
ACEDRINK      555
ACEDRUGS      556
ACEPRISN      557
ACEDIVRC      558
ACEPUNCH      559
ACEHURT1      560
ACESWEAR      561
ACETOUCH      562
ACETTHEM      563
ACEHVSEX      564
RCSGENDR      571
RCSRLTN2      606
CASTHDX2      607                     /* Module 23: Childhood Asthma Prevalence */
CASTHNO2      608
QSTVER        613-614                 /* Questionnaire Version */
QSTLANG       615-616                 /* Questionnaire Language */
_METSTAT      1402
_URBSTAT      1403
MSCODE        1409
_STSTR        1410-1415
_STRWT        1416-1425
_RAWRAKE      1446-1455
_WT2RAKE      1456-1465
_IMPRACE      1471-1472
_CHISPNC      1482                    /* Child Demographic Variables */
_CRACE1       1539-1540
_CPRACE       1541-1542
_CLLCPWT      1585-1594
_DUALUSE      1682
_DUALCOR      1683-1692
_LLCPWT2      1693-1702
_LLCPWT       1751-1760
_RFHLTH       1899                    /* Section 1: Calculated Variables */
_PHYS14D      1900                    /* Section 2: Calculated Variables */
_MENT14D      1901
_HCVU651      1902                    /* Section 3: Calculated Variables */
_TOTINDA      1903                    /* Section 4: Calculated Variables */
_MICHD        1904                    /* Section 6: Calculated Variables */
_LTASTH1      1905
_CASTHM1      1906
_ASTHMS1      1907
_DRDXAR2      1908
_EXTETH3      1909                    /* Section 7: Calculated Variables */
_ALTETH3      1910
_DENVST3      1911
_PRACE1       1968-1969
_MRACE1       1970-1971
_HISPANC      1974
_RACE         1975
_RACEG21      1976
_RACEGR3      1977
_RACEPRV      1978
_SEX          1979
_AGEG5YR      1980-1981
_AGE65YR      1982
_AGE80        1983-1984
_AGE_G        1985
HTIN4         1986-1988
HTM4          1989-1991
WTKG3         1992-1996
_BMI5         1997-2000
_BMI5CAT      2001
_RFBMI5       2002
_CHLDCNT      2003
_EDUCAG       2004
_INCOMG       2005
_SMOKER3      2006                    /* Section 10: Calculated Variables */
_RFSMOK3      2007
DRNKANY5      2008                    /* Section 11: Calculated Variables */
DROCDY3_      2009-2011
_RFBING5      2012
_DRNKWK1      2013-2017
_RFDRHV7      2018
_FLSHOT7      2019                    /* Section 12: Calculated Variables */
_PNEUMO3      2020
_RFSEAT2      2021                    /* Section 14: Calculated Variables */
_RFSEAT3      2022
_DRNKDRV      2023
_RFMAM22      2024                    /* Section 15: Calculated Variables */
_MAM5023      2025
_RFPAP35      2026
_RFPSA23      2027                    /* Section 16: Calculated Variables */
_CLNSCPY      2028                    /* Section 17: Calculated Variables */
_SGMSCPY      2029
_SGMS10Y      2030
_RFBLDS4      2031
_STOLDNA      2032
_VIRCOLN      2033
_SBONTIM      2034
_CRCREC1      2035
_AIDTST4      2036                    /* Section 18: Calculated Variables */
;
*****************************************************************
* TO INCLUDE THE FORMAT ASSIGNEMT STATEMENT REMOVE THE ASTERISK *
* FROM THE BEGINNING OF THE FOLLOWING LINE                      *
*****************************************************************;
* %INCLUDE FORMATIN ;
*************************************************
* THIS SECTION CREATES LABELS FOR THE VARIABLES *
*************************************************;
Label
ACEDEPRS = 'LIVE WITH ANYONE DEPRESSED, MENTALLY ILL, OR SUICIDAL?'
ACEDIVRC = 'WERE YOUR PARENTS DIVORCED/SEPERATED?'
ACEDRINK = 'LIVE WITH A PROBLEM DRINKER/ALCOHOLIC?'
ACEDRUGS = 'LIVE WITH ANYONE WHO USED ILLEGAL DRUGS OR ABUSED PRESCRIPTIONS?'
ACEHURT1 = 'HOW OFTEN DID A PARENT PHYSICALLY HURT YOU IN ANY WAY?'
ACEHVSEX = 'HOW OFTEN DID ANYONE EVER FORCE YOU TO HAVE SEX?'
ACEPRISN = 'LIVE WITH ANYONE WHO SERVED TIME IN PRISON OR JAIL?'
ACEPUNCH = 'HOW OFTEN DID YOUR PARENTS BEAT EACH OTHER UP?'
ACESWEAR = 'HOW OFTEN DID A PARENT SWEAR AT YOU?'
ACETOUCH = 'HOW OFTEN DID ANYONE EVER TOUCH YOU SEXUALLY?'
ACETTHEM = 'HOW OFTEN DID ANYONE MAKE YOU TOUCH THEM SEXUALLY?'
ADDEPEV3 = '(EVER TOLD) YOU HAD A DEPRESSIVE DISORDER'
ALCDAY5 = 'DAYS IN PAST 30 HAD ALCOHOLIC BEVERAGE'
ASTHMA3 = 'EVER TOLD HAD ASTHMA'
ASTHNOW = 'STILL HAVE ASTHMA'
AVEDRNK3 = 'AVG ALCOHOLIC DRINKS PER DAY IN PAST 30'
BIRTHSEX = 'ARE YOU MALE OR FEMALE?'
BLDSTOL1 = 'EVER HAD BLOOD STOOL TEST USING HOME KIT'
BLDSUGAR = 'HOW OFTEN CHECK BLOOD FOR GLUCOSE'
BLIND = 'BLIND OR DIFFICULTY SEEING'
CADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
CAREGIV1 = 'PROVIDED REGULAR CARE FOR FAMILY OR FRIEND'
CASTHDX2 = 'HLTH PRO EVER SAID CHILD HAS ASTHMA'
CASTHNO2 = 'CHILD STILL HAVE ASTHMA?'
CCLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
CDASSIST = 'NEED ASSISTANCE WITH DAY-TO_DAY ACTIVITIES DUE TO CONFUSION OR MEMORY LOSS'
CDDISCUS = 'HAVE YOU DISCUSSED YOUR CONFUSION OR MEMORY LOSS WITH A HEALTH CARE PROFESSIONAL?'
CDHELP = 'WHEN YOU NEED HELP WITH DAY-TO-DAY ACTIVITIES ARE YOU ABLE TO GET IT'
CDHOUSE = 'GIVEN UP DAY-TO-DAY CHORES DUE TO CONFUSION OR MEMORY LOSS'
CDSOCIAL = 'DOES CONFUSION OR MEMORY LOSS INTERFERE WITH WORK OR SOCIAL ACTIVITIES'
CELLFON5 = 'IS THIS A CELL PHONE?'
CELLSEX = 'ARE YOU MALE OR FEMALE?'
CELPHONE = 'CELLULAR TELEPHONE'
CHCCOPD2 = '(EVER TOLD) YOU HAD (COPD) CHRONIC OBSTRUCTIVE PULMONARY DISEASE, EMPHYSEMA OR CHRONIC BRONCHITIS?'
CHCKDNY2 = 'EVER TOLD YOU HAVE KIDNEY DISEASE?'
CHCOCNCR = '(EVER TOLD) YOU HAD ANY OTHER TYPES OF CANCER?'
CHCSCNCR = '(EVER TOLD) YOU HAD SKIN CANCER?'
CHECKUP1 = 'LENGTH OF TIME SINCE LAST ROUTINE CHECKUP'
CHILDREN = 'NUMBER OF CHILDREN IN HOUSEHOLD'
CHKHEMO3 = 'TIMES CHECKED FOR GLYCOSYLATED HEMOGLOBIN'
CIMEMLOS = 'HAVE YOU EXPERIENCED CONFUSION OR MEMORY LOSS THAT IS HAPPENING MORE OFTEN OR IS GETTING WORSE?'
CNCRAGE = 'AGE TOLD HAD CANCER'
CNCRDIFF = 'HOW MANY TYPES OF CANCER?'
CNCRTYP1 = 'TYPE OF CANCER'
COLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
COLGSEX = 'ARE YOU MALE OR FEMALE?'
COLNSCPY = 'HAVE YOU EVER HAD A COLONOSCOPY?'
COLNTEST = 'HOW LONG HAS IT BEEN SINCE YOU HAD COLONOSCOPY?'
CPDEMO1B = 'DO YOU HAVE A CELL PHONE FOR PERSONAL USE?'
CRGVALZD = 'DOES PERSON BEING CARED FOR HAVE ALZHEIMERS DISEASE?'
CRGVEXPT = 'DO YOU EXPECT TO HAVE A RELATIVE YOU WILL NEED TO PROVIDE CARE FOR?'
CRGVHOU1 = 'MANAGED HOUSEHOLD TASKS'
CRGVHRS1 = 'HOW MANY HOURS DO YOU PROVIDE CARE FOR PERSON?'
CRGVLNG1 = 'HOW LONG PROVIDED CARE FOR PERSON.'
CRGVPER1 = 'MANAGED PERSONAL CARE'
CRGVPRB3 = 'WHAT IS THE MAJOR HEALTH PROBLEM, ILLNESS, DISABILITY FOR CARE FOR PERSON?'
CRGVREL4 = 'RELATIONSHIP OF PERSON TO WHOM YOU ARE GIVING CARE?'
CSRVCLIN = 'PARTICIPATE IN CLINICAL TRIAL AS PART OF CANCER TREATMENT?'
CSRVCTL2 = 'IS PAIN UNDER CONTROL?'
CSRVDEIN = 'EVER DENIED INSURANCE COVERAGE BECAUSE OF YOUR CANCER?'
CSRVDOC1 = 'WHAT TYPE OF DOCTOR PROVIDES MAJORITY OF YOUR CARE'
CSRVINSR = 'DID HEALTH INSURANCE PAY FOR ALL OF YOUR CANCER TREATMENT'
CSRVINST = 'INSTRUCTIONS WRITTEN OR PRINTED'
CSRVPAIN = 'CURRENTLY HAVE PHYSICAL PAIN FROM CANCER OR TREATMENT?'
CSRVRTRN = 'EVER RECEIVE INSTRUCTIONS FROM A DOCTOR FOR FOLLOW-UP CHECK-UPS'
CSRVSUM = 'DID YOU RECEIVE A SUMMARY OF CANCER TREATMENTS RECEIVED'
CSRVTRT3 = 'CURRENTLY RECEIVING TREATMENT FOR CANCER'
CSTATE1 = 'DO YOU CURRENTLY LIVE IN  ____(STATE)____?'
CTELENM1 = 'CORRECT TELEPHONE NUMBER?'
CTELNUM1 = 'CORRECT PHONE NUMBER?'
CVDCRHD4 = 'EVER DIAGNOSED WITH ANGINA OR CORONARY HEART DISEASE'
CVDINFR4 = 'EVER DIAGNOSED WITH HEART ATTACK'
CVDSTRK3 = 'EVER DIAGNOSED WITH A STROKE'
DEAF = 'ARE YOU DEAF OR DO YOU HAVE SERIOUS DIFFICULTY HEARING?'
DECIDE = 'DIFFICULTY CONCENTRATING OR REMEMBERING'
DIABAGE3 = 'AGE WHEN TOLD DIABETES'
DIABEDU = 'EVER TAKEN CLASS IN MANAGING DIABETES'
DIABETE4 = '(EVER TOLD) YOU HAD DIABETES'
DIABEYE = 'EVER TOLD DIABETES HAS AFFECTED EYES'
DIFFALON = 'DIFFICULTY DOING ERRANDS ALONE'
DIFFDRES = 'DIFFICULTY DRESSING OR BATHING'
DIFFWALK = 'DIFFICULTY WALKING OR CLIMBING STAIRS'
DISPCODE = 'FINAL DISPOSITION'
DOCTDIAB = 'TIMES SEEN HEALTH PROFESSIONAL FOR DIABETES'
DRNK3GE5 = 'BINGE DRINKING'
DRNKANY5 = 'DRINK ANY ALCOHOLIC BEVERAGES IN PAST 30 DAYS'
DRNKDRI2 = 'DID YOU DRIVE AFTER HAVING TOO MUCH TO DRINK IN THE PAST 30 DAYS?'
DROCDY3_ = 'COMPUTED DRINK-OCCASIONS-PER-DAY'
ECIGARET = 'HAVE YOU EVER USED AN E-CIGARETTE OR OTHER ELECTRONIC VAPING PRODUCT?'
ECIGNOW = 'DO YOU NOW USE E-CIGARETTES, EVERY DAY, SOME DAYS, OR NOT AT ALL?'
EDUCA = 'EDUCATION LEVEL'
EMPLOY1 = 'EMPLOYMENT STATUS'
EXERANY2 = 'EXERCISE IN PAST 30 DAYS'
EYEEXAM1 = 'LAST EYE EXAM WHERE PUPILS WERE DILATED'
FALL12MN = 'HAD FALL PAST TWELVE MONTHS'
FALLINJ4 = 'INJURED IN FALL'
FEETCHK = 'TIMES FEET CHECK FOR SORES/IRRITATIONS'
FEETCHK3 = 'HOW OFTEN CHECK FEET FOR SORES OR IRRITATIONS'
FLSHTMY3 = 'WHEN RECEIVED MOST RECENT SEASONAL FLU SHOT/SPRAY'
FLUSHOT7 = 'ADULT FLU SHOT/SPRAY PAST 12 MOS'
FMONTH = 'FILE MONTH'
GENHLTH = 'GENERAL HEALTH'
HADHYST2 = 'HAD HYSTERECTOMY'
HADMAM = 'HAVE YOU EVER HAD A MAMMOGRAM'
HADPAP2 = 'EVER HAD A PAP TEST'
HAVARTH4 = 'TOLD HAVE ARTHRITIS'
HAVECFS = 'STILL HAVE CHRONIC FATIGUE SYNDROME OR MYALGIC ENCEPHALOMYELITIS'
HAVEHEPB = 'TOLD  HAD HEPATITIS B'
HAVEHEPC = 'STILL HAVE HEPATITIS C'
HEIGHT3 = 'REPORTED HEIGHT IN FEET AND INCHES'
HHADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
HIVRISK5 = 'DO ANY HIGH RISK SITUATIONS APPLY'
HIVTST7 = 'EVER TESTED H.I.V.'
HIVTSTD3 = 'MONTH AND YEAR OF LAST HIV TEST'
HLTHCVR1 = 'PRIMARY HEALTH INSURANCE COVERAGE'
HLTHPLN1 = 'HAVE ANY HEALTH CARE COVERAGE'
HOWLONG = 'HOW LONG SINCE LAST MAMMOGRAM'
HPLSTTST = 'HOW LONG SINCE YOUR LAST HPV TEST?'
HPVADSHT = 'NUMBER OF HPV SHOTS RECEIVED'
HPVADVC4 = 'EVER HAD AN H.P.V. VACCINATION?'
HPVTEST = 'HAVE YOU EVER HAD AN HPV TEST?'
HTIN4 = 'COMPUTED HEIGHT IN INCHES'
HTM4 = 'COMPUTED HEIGHT IN METERS'
IDATE = 'INTERVIEW DATE'
IDAY = 'INTERVIEW DAY'
IMFVPLA1 = 'WHERE DID YOU GET YOUR LAST FLU SHOT/VACCINE?'
IMONTH = 'INTERVIEW MONTH'
INCOME2 = 'INCOME LEVEL'
INSULIN1 = 'NOW TAKING INSULIN'
IYEAR = 'INTERVIEW YEAR'
LADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
LANDLINE = 'DO YOU ALSO HAVE A LANDLINE TELEPHONE?'
LANDSEX = 'ARE YOU MALE OR FEMALE?'
LASTDEN4 = 'LAST VISITED DENTIST OR DENTAL CLINIC'
LASTPAP2 = 'HOW LONG SINCE LAST PAP TEST'
LASTSMK2 = 'INTERVAL SINCE LAST SMOKED'
LCSCTSCN = 'DID YOU HAVE A CT OR CAT SCAN?'
LCSFIRST = 'HOW OLD WHEN YOU FIRST STARTED SMOKING?'
LCSLAST = 'HOW OLD WHEN YOU LAST SMOKED?'
LCSNUMCG = 'ON AVERAGE, HOW MANY CIGARETTES DO YOU SMOKE EACH DAY?'
LSTBLDS4 = 'HOW LONG SINCE YOU HAD BLOOD STOOL TEST?'
MARIJAN1 = 'DURING THE PAST 30 DAYS, ON HOW MANY DAYS DID YOU USE MARIJUANA OR HASHISH?'
MARITAL = 'MARITAL STATUS'
MAXDRNKS = 'MOST DRINKS ON SINGLE OCCASION PAST 30 DAYS'
MEDCOST = 'COULD NOT SEE DR. BECAUSE OF COST'
MEDSHEPB = 'CURRENTLY TAKING MEDICINE FOR HEPATITIS B'
MENTHLTH = 'NUMBER OF DAYS MENTAL HEALTH NOT GOOD'
MSCODE = 'METROPOLITAN STATUS CODE'
NUMADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
NUMHHOL3 = 'HOUSEHOLD TELEPHONES'
NUMMEN = 'NUMBER OF ADULT MEN IN HOUSEHOLD'
NUMPHON3 = 'RESIDENTIAL PHONES'
NUMWOMEN = 'NUMBER OF ADULT WOMEN IN HOUSEHOLD'
PCDMDEC1 = 'WHO MADE THE DECISION WITH YOU TO HAVE PSA TEST?'
PCPSAAD3 = 'HAS A HEALTH PROFESSIONAL EVER TALKED WITH YOU ABOUT THE ADVANTAGES OF THE PSA TEST?'
PCPSADE1 = 'WHY WAS PSA TEST DONE?'
PCPSADI1 = 'HAS A HEALTH PROFESSIONAL EVER TALKED WITH YOU ABOUT THE DISADVANTAGES OF THE PSA TEST?'
PCPSARE1 = 'HAS A DOCTOR EVER RECOMMENDED THAT YOU HAVE A PSA TEST?'
PCPSARS1 = 'WHAT WAS THE MAIN REASON YOU HAD THIS PSA TEST?'
PDIABTST = 'HAD A TEST FOR HIGH BLOOD SUGAR IN PAST THREE YEARS'
PERSDOC2 = 'MULTIPLE HEALTH CARE PROFESSIONALS'
PHYSHLTH = 'NUMBER OF DAYS PHYSICAL HEALTH NOT GOOD'
PNEUVAC4 = 'PNEUMONIA SHOT EVER'
POORHLTH = 'POOR PHYSICAL OR MENTAL HEALTH'
PREDIAB1 = 'EVER BEEN TOLD YOU HAVE PRE-DIABETES OR BORDERLINE DIABETES'
PREGNANT = 'PREGNANCY STATUS'
PRIRHEPC = 'WERE YOU TREATED FOR HEPATITIS C PRIOR TO 2015'
PSATEST1 = 'EVER HAD PSA TEST'
PSATIME = 'TIME SINCE LAST PSA TEST'
PVTRESD1 = 'PRIVATE RESIDENCE?'
PVTRESD3 = 'DO YOU LIVE IN A PRIVATE RESIDENCE?'
QSTLANG = 'LANGUAGE IDENTIFIER'
QSTVER = 'QUESTIONNAIRE VERSION IDENTIFIER'
RCSGENDR = 'GENDER OF CHILD'
RCSRLTN2 = 'RELATIONSHIP TO CHILD'
RENTHOM1 = 'OWN OR RENT HOME'
RESPSLCT = 'RESPONDENT SELECTION'
RMVTETH4 = 'NUMBER OF PERMANENT TEETH REMOVED'
RSNMRJN1 = 'WHAT WAS THE REASON YOU USED MARIJUANA?'
SAFETIME = 'SAFE TIME TO TALK?'
SDNATEST = 'HOW LONG SINCE YOU HAD STOOL DNA?'
SEATBELT = 'HOW OFTEN USE SEATBELTS IN CAR?'
SEQNO = 'ANNUAL SEQUENCE NUMBER'
SEXVAR = 'SEX OF RESPONDENT'
SHINGLE2 = 'HAVE YOU EVER HAD THE SHINGLES OR ZOSTER VACCINE?'
SIGMSCPY = 'HAVE YOU EVER HAD A SIGMOIDOSCOPY?'
SIGMTEST = 'HOW LONG HAS IT BEEN SINCE YOU HAD SIGMOIDOSCOPY?'
SLEPTIM1 = 'HOW MUCH TIME DO YOU SLEEP'
SMOKDAY2 = 'FREQUENCY OF DAYS NOW SMOKING'
SMOKE100 = 'SMOKED AT LEAST 100 CIGARETTES'
SOFEMALE = 'SEXUAL ORIENTATION'
SOMALE = 'SEXUAL ORIENTATION'
STATERE1 = 'RESIDENT OF STATE'
STOOLDNA = 'EVER HAD STOOL DNA TEST?'
STOPSMK2 = 'STOPPED SMOKING IN PAST 12 MONTHS'
TETANUS1 = 'RECEIVED TETANUS SHOT SINCE 2005?'
TOLDCFS = 'TOLD HAD CHRONIC FATIGUE SYNDROME OR MYALGIC ENCEPHALOMYELITIS'
TOLDHEPC = 'TOLD HAD HEPATITIS C'
TRETHEPC = 'TREATED FOR HEPATITIS C'
TRNSGNDR = 'DO YOU CONSIDER YOURSELF TO BE TRANSGENDER?'
USEMRJN2 = 'DURING THE PAST 30 DAYS, HOW DID YOU PRIMARILY USE MARIJUANA?'
USENOW3 = 'USE OF SMOKELESS TOBACCO PRODUCTS'
VCLNTEST = 'HOW LONG HAS IT BEEN SINCE YOU HAD VIRTUAL COLONOSCOPY?'
VETERAN3 = 'ARE YOU A VETERAN'
VIRCOLON = 'HAVE YOU EVER HAD A VIRTUAL COLONOSCOPY?'
WEIGHT2 = 'REPORTED WEIGHT IN POUNDS'
WORKCFS = 'HOW MANY HOURS A WEEK ARE YOU BEEN ABLE TO WORK'
WTKG3 = 'COMPUTED WEIGHT IN KILOGRAMS'
_AGE65YR = 'REPORTED AGE IN TWO AGE GROUPS CALCULATED VARIABLE'
_AGE80 = 'IMPUTED AGE VALUE COLLAPSED ABOVE 80'
_AGEG5YR = 'REPORTED AGE IN FIVE-YEAR AGE CATEGORIES CALCULATED VARIABLE'
_AGE_G = 'IMPUTED AGE IN SIX GROUPS'
_AIDTST4 = 'EVER BEEN TESTED FOR HIV CALCULATED VARIABLE'
_ALTETH3 = 'ADULTS AGED 65+ WHO HAVE HAD ALL THEIR NATURAL TEETH EXTRACTED'
_ASTHMS1 = 'COMPUTED ASTHMA STATUS'
_BMI5 = 'COMPUTED BODY MASS INDEX'
_BMI5CAT = 'COMPUTED BODY MASS INDEX CATEGORIES'
_CASTHM1 = 'CURRENT ASTHMA CALCULATED VARIABLE'
_CHISPNC = 'CHILD HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_CHLDCNT = 'COMPUTED NUMBER OF CHILDREN IN HOUSEHOLD'
_CLLCPWT = 'FINAL CHILD WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_CLNSCPY = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A COLONOSCOPY WITHIN THE PAST TEN YEARS'
_CPRACE = 'PREFERRED CHILD RACE CATEGORIES'
_CRACE1 = 'CHILD NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_CRCREC1 = 'RESPONDENTS AGED 50-75 WHO HAVE FULLY MET THE USPSTF RECOMMENDATIONS'
_DENVST3 = 'ADULTS WHO HAVE VISITED A DENTIST, DENTAL HYGENIST OR DENTAL CLINIC WITHIN THE PAST YEAR'
_DRDXAR2 = 'RESPONDENTS DIAGNOSED WITH ARTHRITIS'
_DRNKDRV = 'DRINKING AND DRIVING'
_DRNKWK1 = 'COMPUTED NUMBER OF DRINKS OF ALCOHOL BEVERAGES PER WEEK'
_DUALCOR = 'DUAL PHONE USE CORRECTION FACTOR'
_DUALUSE = 'DUAL PHONE USE CATEGORIES'
_EDUCAG = 'COMPUTED LEVEL OF EDUCATION COMPLETED CATEGORIES'
_EXTETH3 = 'RISK FACTOR FOR HAVING HAD PERMANENT TEETH EXTRACTED'
_FLSHOT7 = 'FLU SHOT CALCULATED VARIABLE'
_HCVU651 = 'RESPONDENTS AGED 18-64 WITH HEALTH CARE COVERAGE'
_HISPANC = 'HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_IMPRACE = 'IMPUTED RACE/ETHNICITY VALUE'
_INCOMG = 'COMPUTED INCOME CATEGORIES'
_LLCPWT = 'FINAL WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_LLCPWT2 = 'TRUNCATED DESIGN WEIGHT USED IN ADULT COMBINED LAN  LINE AND CELL PHONE RAKING'
_LTASTH1 = 'LIFETIME ASTHMA CALCULATED VARIABLE'
_MAM5023 = 'WOMEN RESPONDENTS AGED 50-74 WHO HAVE HAD A MAMMOGRAM IN THE PAST TWO YEARS'
_MENT14D = 'COMPUTED MENTAL HEALTH STATUS'
_METSTAT = 'METROPOLITAN STATUS'
_MICHD = 'RESPONDENTS THAT HAVE EVER REPORTED HAVING CORONARY HEART DISEASE (CHD) OR MYOCARDIAL INFARCTION (MI)'
_MRACE1 = 'CALCULATED NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_PHYS14D = 'COMPUTED PHYSICAL HEALTH STATUS'
_PNEUMO3 = 'PNEUMONIA VACCINATION CALCULATED VARIABLE'
_PRACE1 = 'COMPUTED PREFERRED RACE'
_PSU = 'PRIMARY SAMPLING UNIT'
_RACE = 'COMPUTED RACE-ETHNICITY GROUPING'
_RACEG21 = 'COMPUTED NON-HISPANIC WHITES/ALL OTHERS RACE CATEGORIES RACE/ETHNIC GROUP CODES USED IN POST-STRATIFICATION.'
_RACEGR3 = 'COMPUTED FIVE LEVEL RACE/ETHNICITY CATEGORY.'
_RACEPRV = 'COMPUTED RACE GROUPS USED FOR INTERNET PREVALENCE TABLES'
_RAWRAKE = 'RAW WEIGHTING FACTOR USED IN RAKING'
_RFBING5 = 'BINGE DRINKING CALCULATED VARIABLE'
_RFBLDS4 = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A BLOOD STOOL TEST WITHIN THE PAST YEAR'
_RFBMI5 = 'OVERWEIGHT OR OBESE CALCULATED VARIABLE'
_RFDRHV7 = 'HEAVY ALCOHOL CONSUMPTION  CALCULATED VARIABLE'
_RFHLTH = 'ADULTS WITH GOOD OR BETTER HEALTH'
_RFMAM22 = 'WOMEN RESPONDENTS AGED 40+ WHO HAVE HAD A MAMMOGRAM IN THE PAST TWO YEARS'
_RFPAP35 = 'WOMEN RESPONDENTS AGED 21-65 WHO HAVE HAD A PAP TEST IN THE PAST THREE YEARS'
_RFPSA23 = 'MALE RESPONDENTS AGED 40+ WHO HAVE HAD A PSA TEST IN THE PAST 2 YEARS'
_RFSEAT2 = 'ALWAYS OR NEARLY ALWAYS WEAR SEAT BELTS'
_RFSEAT3 = 'ALWAYS WEAR SEAT BELTS'
_RFSMOK3 = 'CURRENT SMOKING CALCULATED VARIABLE'
_SBONTIM = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A SIGMOIDOSCOPY WITHIN THE PAST TEN YEARS AND A BLOOD STOOL TEST IN THE PAST YEAR'
_SEX = 'CALCULATED SEX VARIABLE'
_SGMS10Y = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A SIGMOIDOSCOPY WITHIN THE PAST TEN YEARS'
_SGMSCPY = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A SIGMOIDOSCOPY WITHIN THE PAST FIVE YEARS'
_SMOKER3 = 'COMPUTED SMOKING STATUS'
_STATE = 'STATE FIPS CODE'
_STOLDNA = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A STOOL DNA TEST WITHIN THE PAST THREE YEARS'
_STRWT = 'STRATUM WEIGHT'
_STSTR = 'SAMPLE DESIGN STRATIFICATION VARIABLE'
_TOTINDA = 'LEISURE TIME PHYSICAL ACTIVITY CALCULATED VARIABLE'
_URBSTAT = 'URBAN/RURAL STATUS'
_VIRCOLN = 'RESPONDENTS AGED 50-75 WHO HAVE HAD A VIRTUAL COLONOSCOPY WITHIN THE PAST FIVE YEARS'
_WT2RAKE = 'DESIGN WEIGHT USED IN RAKING'
;
RUN;
